==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkMatrix3x3.java <==
// java wrapper for vtkMatrix3x3 object
//

package vtk;
import vtk.*;

public class vtkMatrix3x3 extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeepCopy_2(vtkMatrix3x3 id0);
  public void DeepCopy(vtkMatrix3x3 id0)
    { DeepCopy_2(id0); }

  private native void DeepCopy_3(double id0[],vtkMatrix3x3 id1);
  public void DeepCopy(double id0[],vtkMatrix3x3 id1)
    { DeepCopy_3(id0,id1); }

  private native void DeepCopy_4(double id0[],double id1[]);
  public void DeepCopy(double id0[],double id1[])
    { DeepCopy_4(id0,id1); }

  private native void DeepCopy_5(double id0[]);
  public void DeepCopy(double id0[])
    { DeepCopy_5(id0); }

  private native void Zero_6();
  public void Zero()
    { Zero_6(); }

  private native void Zero_7(double id0[]);
  public void Zero(double id0[])
    { Zero_7(id0); }

  private native void Identity_8();
  public void Identity()
    { Identity_8(); }

  private native void Identity_9(double id0[]);
  public void Identity(double id0[])
    { Identity_9(id0); }

  private native void Invert_10(vtkMatrix3x3 id0,vtkMatrix3x3 id1);
  public void Invert(vtkMatrix3x3 id0,vtkMatrix3x3 id1)
    { Invert_10(id0,id1); }

  private native void Invert_11();
  public void Invert()
    { Invert_11(); }

  private native void Invert_12(double id0[],double id1[]);
  public void Invert(double id0[],double id1[])
    { Invert_12(id0,id1); }

  private native void Transpose_13(vtkMatrix3x3 id0,vtkMatrix3x3 id1);
  public void Transpose(vtkMatrix3x3 id0,vtkMatrix3x3 id1)
    { Transpose_13(id0,id1); }

  private native void Transpose_14();
  public void Transpose()
    { Transpose_14(); }

  private native void Transpose_15(double id0[],double id1[]);
  public void Transpose(double id0[],double id1[])
    { Transpose_15(id0,id1); }

  private native void MultiplyPoint_16(double id0[],double id1[]);
  public void MultiplyPoint(double id0[],double id1[])
    { MultiplyPoint_16(id0,id1); }

  private native void MultiplyPoint_17(double id0[],double id1[],double id2[]);
  public void MultiplyPoint(double id0[],double id1[],double id2[])
    { MultiplyPoint_17(id0,id1,id2); }

  private native void Multiply3x3_18(vtkMatrix3x3 id0,vtkMatrix3x3 id1,vtkMatrix3x3 id2);
  public void Multiply3x3(vtkMatrix3x3 id0,vtkMatrix3x3 id1,vtkMatrix3x3 id2)
    { Multiply3x3_18(id0,id1,id2); }

  private native void Multiply3x3_19(double id0[],double id1[],double id2[]);
  public void Multiply3x3(double id0[],double id1[],double id2[])
    { Multiply3x3_19(id0,id1,id2); }

  private native void Adjoint_20(vtkMatrix3x3 id0,vtkMatrix3x3 id1);
  public void Adjoint(vtkMatrix3x3 id0,vtkMatrix3x3 id1)
    { Adjoint_20(id0,id1); }

  private native void Adjoint_21(double id0[],double id1[]);
  public void Adjoint(double id0[],double id1[])
    { Adjoint_21(id0,id1); }

  private native double Determinant_22();
  public double Determinant()
    { return Determinant_22(); }

  private native double Determinant_23(double id0[]);
  public double Determinant(double id0[])
    { return Determinant_23(id0); }

  private native void SetElement_24(int id0,int id1,double id2);
  public void SetElement(int id0,int id1,double id2)
    { SetElement_24(id0,id1,id2); }

  private native double GetElement_25(int id0,int id1);
  public double GetElement(int id0,int id1)
    { return GetElement_25(id0,id1); }

  private native double Determinant_26(vtkMatrix3x3 id0);
  public double Determinant(vtkMatrix3x3 id0)
    { return Determinant_26(id0); }

  private native void PointMultiply_27(double id0[],double id1[],double id2[]);
  public void PointMultiply(double id0[],double id1[],double id2[])
    { PointMultiply_27(id0,id1,id2); }

  private native boolean IsIdentity_28();
  public boolean IsIdentity()
    { return IsIdentity_28(); }

  public vtkMatrix3x3() { super(); }

  public vtkMatrix3x3(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-4-aarch64.pkg.tar.xz: vtk/vtkMatrix3x3.java <==
// java wrapper for vtkMatrix3x3 object
//

package vtk;
import vtk.*;

public class vtkMatrix3x3 extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeepCopy_2(vtkMatrix3x3 id0);
  public void DeepCopy(vtkMatrix3x3 id0)
    { DeepCopy_2(id0); }

  private native void DeepCopy_3(double id0[],vtkMatrix3x3 id1);
  public void DeepCopy(double id0[],vtkMatrix3x3 id1)
    { DeepCopy_3(id0,id1); }

  private native void DeepCopy_4(double id0[],double id1[]);
  public void DeepCopy(double id0[],double id1[])
    { DeepCopy_4(id0,id1); }

  private native void DeepCopy_5(double id0[]);
  public void DeepCopy(double id0[])
    { DeepCopy_5(id0); }

  private native void Zero_6();
  public void Zero()
    { Zero_6(); }

  private native void Zero_7(double id0[]);
  public void Zero(double id0[])
    { Zero_7(id0); }

  private native void Identity_8();
  public void Identity()
    { Identity_8(); }

  private native void Identity_9(double id0[]);
  public void Identity(double id0[])
    { Identity_9(id0); }

  private native void Invert_10(vtkMatrix3x3 id0,vtkMatrix3x3 id1);
  public void Invert(vtkMatrix3x3 id0,vtkMatrix3x3 id1)
    { Invert_10(id0,id1); }

  private native void Invert_11();
  public void Invert()
    { Invert_11(); }

  private native void Invert_12(double id0[],double id1[]);
  public void Invert(double id0[],double id1[])
    { Invert_12(id0,id1); }

  private native void Transpose_13(vtkMatrix3x3 id0,vtkMatrix3x3 id1);
  public void Transpose(vtkMatrix3x3 id0,vtkMatrix3x3 id1)
    { Transpose_13(id0,id1); }

  private native void Transpose_14();
  public void Transpose()
    { Transpose_14(); }

  private native void Transpose_15(double id0[],double id1[]);
  public void Transpose(double id0[],double id1[])
    { Transpose_15(id0,id1); }

  private native void MultiplyPoint_16(double id0[],double id1[]);
  public void MultiplyPoint(double id0[],double id1[])
    { MultiplyPoint_16(id0,id1); }

  private native void MultiplyPoint_17(double id0[],double id1[],double id2[]);
  public void MultiplyPoint(double id0[],double id1[],double id2[])
    { MultiplyPoint_17(id0,id1,id2); }

  private native void Multiply3x3_18(vtkMatrix3x3 id0,vtkMatrix3x3 id1,vtkMatrix3x3 id2);
  public void Multiply3x3(vtkMatrix3x3 id0,vtkMatrix3x3 id1,vtkMatrix3x3 id2)
    { Multiply3x3_18(id0,id1,id2); }

  private native void Multiply3x3_19(double id0[],double id1[],double id2[]);
  public void Multiply3x3(double id0[],double id1[],double id2[])
    { Multiply3x3_19(id0,id1,id2); }

  private native void Adjoint_20(vtkMatrix3x3 id0,vtkMatrix3x3 id1);
  public void Adjoint(vtkMatrix3x3 id0,vtkMatrix3x3 id1)
    { Adjoint_20(id0,id1); }

  private native void Adjoint_21(double id0[],double id1[]);
  public void Adjoint(double id0[],double id1[])
    { Adjoint_21(id0,id1); }

  private native double Determinant_22();
  public double Determinant()
    { return Determinant_22(); }

  private native double Determinant_23(double id0[]);
  public double Determinant(double id0[])
    { return Determinant_23(id0); }

  private native void SetElement_24(int id0,int id1,double id2);
  public void SetElement(int id0,int id1,double id2)
    { SetElement_24(id0,id1,id2); }

  private native double GetElement_25(int id0,int id1);
  public double GetElement(int id0,int id1)
    { return GetElement_25(id0,id1); }

  private native double Determinant_26(vtkMatrix3x3 id0);
  public double Determinant(vtkMatrix3x3 id0)
    { return Determinant_26(id0); }

  private native void PointMultiply_27(double id0[],double id1[],double id2[]);
  public void PointMultiply(double id0[],double id1[],double id2[])
    { PointMultiply_27(id0,id1,id2); }

  private native boolean IsIdentity_28();
  public boolean IsIdentity()
    { return IsIdentity_28(); }

  public vtkMatrix3x3() { super(); }

  public vtkMatrix3x3(long id) { super(id); }
  public native long   VTKInit();

}
